@@ -88,12 +88,13 @@ public:
     QString titleLogoURL() const { return m_titleLogoURL; }
     bool titleShadow() const { return m_titleShadow; }
     int  borderSize() const { return m_borderSize; }
+    int titlebarStyle() const { return m_titlebarStyle; }
     int buttonType() const { return m_buttonType; }
     bool customColors() const { return m_customColors; }
     bool useTitleProps() const { return m_useTitleProps; }
-    float iconSize() const { return m_iconSize; }
     bool animateButtons() const { return m_animateButtons; }
     bool redCloseButton() const { return m_redCloseButton; }
+    float iconSize() const { return m_iconSize; }
     bool iconShadow() const { return m_iconShadow; }
     bool menuClose() const { return m_menuClose; }
     Qt::AlignmentFlags titleAlign() const { return m_titleAlign; }
@@ -111,6 +112,7 @@ private:
     int  m_buttonType;
     bool m_customColors;
     float m_iconSize;
+    int m_titlebarStyle;
     bool m_customIconColors;
     QColor m_aFgColor;
     QColor m_aBgColor;
