@@ -22,27 +22,27 @@
   Boston, MA  02110-1301  USA.
 */
 
-// #include <kwin/options.h>
+#include <kdebug.h>
 
 #include <math.h>
 
-#include <kdebug.h>
 #include <qbitmap.h>
 #include <qcursor.h>
 #include <qimage.h>
 #include <qpainter.h>
 #include <qpixmap.h>
-#include <kpixmap.h>
-#include <kpixmapeffect.h>
-#include <kdecoration.h>
 #include <qtooltip.h>
 #include <qtimer.h>
 
-#include "SUSE2button.h"
-#include "SUSE2button.moc"
-#include "SUSE2client.h"
+#include <kpixmap.h>
+#include <kpixmapeffect.h>
+#include <kdecoration.h>
+
 #include "misc.h"
 #include "shadow.h"
+#include "SUSE2client.h"
+#include "SUSE2button.h"
+#include "SUSE2button.moc"
 
 #define PLASTIK_FLAT 0
 #define LIPSTIK_FLAT 1
@@ -53,33 +53,16 @@
 namespace KWinSUSE2
 {
 
-static const uint TIMERINTERVAL = 50; // msec
-static const uint ANIMATIONSTEPS = 4;
-
-SUSE2Button::SUSE2Button(SUSE2Client *parent, const char *name,
-                             const QString& tip, ButtonType type,
-                             int size, bool toggle, int btns)
-    : QButton(parent->widget(), name),
+SUSE2Button::SUSE2Button(ButtonType type, SUSE2Client *parent, const char *name)
+    : KCommonDecorationButton(type, parent, name),
     m_client(parent),
-    m_lastMouse(NoButton),
-    m_realizeButtons(btns),
-    m_size(size),
-    m_type(type),
+    m_iconType(NumButtonIcons),
     hover(false)
 {
-    QToolTip::add( this, tip );
-    setCursor(ArrowCursor);
+    memset(lipstikCache, 0, sizeof(QPixmap*)*(8 + 3*(ANIMATIONSTEPS+1))*2); // set elements to 0
 
     setBackgroundMode(NoBackground);
 
-    setToggleButton(toggle);
-
-    if(m_size < 10) { m_size = 10; }
-
-    setFixedSize(m_size, m_size);
-
-    setDeco();
-
     animTmr = new QTimer(this);
     connect(animTmr, SIGNAL(timeout() ), this, SLOT(animate() ) );
     animProgress = 0;
@@ -87,85 +70,75 @@ SUSE2Button::SUSE2Button(SUSE2Client *parent, const char *name,
 
 SUSE2Button::~SUSE2Button()
 {
+    for (uint t = 0; t < (8 + 3*ANIMATIONSTEPS+1); ++t)
+        for (int i = 0; i < 2; ++i)
+            delete lipstikCache[t][i];
 }
 
-QSize SUSE2Button::sizeHint() const
+void SUSE2Button::reset(unsigned long changed)
 {
-    return QSize(m_size, m_size);
-}
+    if (changed&DecorationReset || changed&ManualReset || changed&SizeChange || changed&StateChange) {
+        switch (type()) {
+            case CloseButton:
+                m_iconType = CloseIcon;
+                break;
+            case HelpButton:
+                m_iconType = HelpIcon;
+                break;
+            case MinButton:
+                m_iconType = MinIcon;
+                break;
+            case MaxButton:
+                if (isOn()) {
+                    m_iconType = MaxRestoreIcon;
+                } else {
+                    m_iconType = MaxIcon;
+                }
+                break;
+            case OnAllDesktopsButton:
+                if (isOn()) {
+                    m_iconType = NotOnAllDesktopsIcon;
+                } else {
+                    m_iconType = OnAllDesktopsIcon;
+                }
+                break;
+            case ShadeButton:
+                if (isOn()) {
+                    m_iconType = UnShadeIcon;
+                } else {
+                    m_iconType = ShadeIcon;
+                }
+                break;
+            case AboveButton:
+                if (isOn()) {
+                    m_iconType = NoKeepAboveIcon;
+                } else {
+                    m_iconType = KeepAboveIcon;
+                }
+                break;
+            case BelowButton:
+                if (isOn()) {
+                    m_iconType = NoKeepBelowIcon;
+                } else {
+                    m_iconType = KeepBelowIcon;
+                }
+                break;
+            default:
+                m_iconType = NumButtonIcons;
+                break;
+        }
 
-void SUSE2Button::setSize(int s)
-{
-    m_size = s;
-    if(m_size < 10) { m_size = 10; }
-    setFixedSize(m_size, m_size);
-    setDeco();
-}
+        for (uint t = 0; t < (8 + 3*(ANIMATIONSTEPS+1)); ++t) {
+            for (int i = 0; i < 2; ++i) {
+                if (lipstikCache[t][i]) {
+                    delete lipstikCache[t][i];
+                    lipstikCache[t][i] = 0;
+               }
+           }
+        }
 
-void SUSE2Button::setOn(bool on)
-{
-    QButton::setOn(on);
-    setDeco();
-}
-
-void SUSE2Button::setDeco()
-{
-    switch (m_type) {
-        case CloseButton:
-            btnType = CloseIcon;
-            break;
-        case HelpButton:
-            btnType = HelpIcon;
-            break;
-        case MinButton:
-            btnType = MinIcon;
-            break;
-        case MaxButton:
-            if (isOn()) {
-                btnType = MaxRestoreIcon;
-            } else {
-                btnType = MaxIcon;
-            }
-            break;
-        case OnAllDesktopsButton:
-            if (isOn()) {
-                btnType = NotOnAllDesktopsIcon;
-            } else {
-                btnType = OnAllDesktopsIcon;
-            }
-            break;
-        case ShadeButton:
-            if (isOn()) {
-                btnType = UnShadeIcon;
-            } else {
-                btnType = ShadeIcon;
-            }
-            break;
-        case AboveButton:
-            if (isOn()) {
-                btnType = NoKeepAboveIcon;
-            } else {
-                btnType = KeepAboveIcon;
-            }
-            break;
-        case BelowButton:
-            if (isOn()) {
-                btnType = NoKeepBelowIcon;
-            } else {
-                btnType = KeepBelowIcon;
-            }
-            break;
-        default:
-            btnType = NumButtonIcons;
-            break;
+        this->update();
     }
-
-    this->update();
-}
-
-void SUSE2Button::setTipText(const QString &tip) {
-    QToolTip::remove(this );
-    QToolTip::add(this, tip );
 }
 
 void SUSE2Button::animate()
@@ -213,37 +186,14 @@ void SUSE2Button::leaveEvent(QEvent *e)
 //     repaint(false);
 }
 
-void SUSE2Button::mousePressEvent(QMouseEvent* e)
-{
-    m_lastMouse = e->button();
-    // pass on event after changing button to LeftButton
-    QMouseEvent me(e->type(), e->pos(), e->globalPos(),
-                   (e->button()&m_realizeButtons)?LeftButton:NoButton, e->state());
-
-    QButton::mousePressEvent(&me);
-}
-
-void SUSE2Button::mouseReleaseEvent(QMouseEvent* e)
-{
-    m_lastMouse = e->button();
-    // pass on event after changing button to LeftButton
-    QMouseEvent me(e->type(), e->pos(), e->globalPos(),
-                    (e->button()&m_realizeButtons)?LeftButton:NoButton, e->state());
-
-    QButton::mouseReleaseEvent(&me);
-}
-
 void SUSE2Button::drawButton(QPainter *painter)
 {
-    if (!Handler()->initialized())
-        return;
-
     int type = Handler()->buttonType();
 
     switch (type) {
         case PLASTIK_FLAT:
         case LIPSTIK_FLAT:
-	case LIPSTIK_BRIGHT:
+        case LIPSTIK_BRIGHT:
             drawPlastikBtn(painter);
             break;
         case PLASTIK_3D:
@@ -258,7 +208,7 @@ void SUSE2Button::drawButton(QPainter *painter)
 
 void SUSE2Button::drawPlastikBtn(QPainter *painter)
 {
-    QRect r(0,0,width(),height());
+    QRect r(0, 0, width(), height());
 
     bool active = m_client->isActive();
     bool down = isDown();
@@ -266,7 +216,7 @@ void SUSE2Button::drawPlastikBtn(QPainter *painter)
     KPixmap tempKPixmap;
 
     QColor highlightColor;
-    if(m_type == CloseButton) {
+    if(type() == CloseButton) {
         highlightColor = QColor(255,64,0);
     } else {
         highlightColor = Qt::white;
@@ -281,7 +231,7 @@ void SUSE2Button::drawPlastikBtn(QPainter *painter)
     QColor surfaceBottom = alphaBlendColors(Handler()->getColor(TitleGradientTo, active),
             Qt::white, 220);
 
-    if (m_type == CloseButton && active && Handler()->redCloseButton()) {
+    if (type() == CloseButton && active && Handler()->redCloseButton()) {
         contourTop = QColor(170,70,70);
         contourBottom = QColor(120,50,50);
         surfaceTop = QColor(255,70,70);
@@ -314,9 +264,9 @@ void SUSE2Button::drawPlastikBtn(QPainter *painter)
     QPainter bP(&buffer);
 
     // fill with the titlebar background
-    bP.drawTiledPixmap(0, 0, width(), width(), backgroundTile, 0, TOPMARGIN );
+    bP.drawTiledPixmap(0, 0, width(), width(), backgroundTile, 0, TOPMARGIN);
 
-    if (m_type == MenuButton) {
+    if (type() == MenuButton) {
         KPixmap menuIcon(m_client->icon().pixmap( QIconSet::Small, QIconSet::Normal));
         if (width() < menuIcon.width() || height() < menuIcon.height() ) {
             menuIcon.convertFromImage( menuIcon.convertToImage().smoothScale(width(), height()));
@@ -396,9 +346,9 @@ void SUSE2Button::drawPlastikBtn(QPainter *painter)
         if ((s + r.height())%2 != 0) --s;
 
         if (down) {
-            deco = active ? Handler()->buttonPixmap(btnType, s, A_FG_LIGHT) : Handler()->buttonPixmap(btnType, s, I_FG_LIGHT);
+            deco = active ? Handler()->buttonPixmap(m_iconType, s, ActiveDown) : Handler()->buttonPixmap(m_iconType, s, InactiveDown);
         } else {
-            deco = active ? Handler()->buttonPixmap(btnType, s, A_FG_DARK) : Handler()->buttonPixmap(btnType, s, I_FG_DARK);
+            deco = active ? Handler()->buttonPixmap(m_iconType, s, ActiveUp) : Handler()->buttonPixmap(m_iconType, s, InactiveUp);
         }
         dX = r.x()+(r.width()-deco.width())/2;
         dY = r.y()+(r.height()-deco.height())/2;
@@ -408,7 +358,7 @@ void SUSE2Button::drawPlastikBtn(QPainter *painter)
 
         if(active && !down &&
            (Handler()->useTitleProps() && Handler()->titleShadow() || Handler()->iconShadow())) {
-            bP.drawPixmap(dX+1, dY+1, Handler()->buttonPixmap(btnType, s, SHADOW));
+            bP.drawPixmap(dX+1, dY+1, Handler()->buttonPixmap(m_iconType, s, Shadow));
         }
 
         bP.drawPixmap(dX, dY, deco);
@@ -420,10 +370,7 @@ void SUSE2Button::drawPlastikBtn(QPainter *painter)
 
 void SUSE2Button::drawLipstikBtn(QPainter *painter)
 {
-    QRect r(0,0,width(),height());
-
-    pixmapCache = new QIntCache<CacheEntry>(150000, 499);
-    pixmapCache->setAutoDelete(true);
+    QRect r(0, 0, width(), height());
 
     bool active = m_client->isActive();
     bool down = isDown();
@@ -434,9 +381,9 @@ void SUSE2Button::drawLipstikBtn(QPainter *painter)
     QPainter bP(&buffer);
 
     // fill with the titlebar background
-    bP.drawTiledPixmap(0, 0, width(), width(), backgroundTile, 0, TOPMARGIN );
+    bP.drawTiledPixmap(0, 0, width(), width(), backgroundTile, 0, TOPMARGIN);
 
-    if (m_type == MenuButton)
+    if (type() == MenuButton)
     {
         KPixmap menuIcon(m_client->icon().pixmap( QIconSet::Small, QIconSet::Normal));
         if (width() < menuIcon.width() || height() < menuIcon.height() ) {
@@ -449,7 +396,7 @@ void SUSE2Button::drawLipstikBtn(QPainter *painter)
         renderBtnContour(&bP, r);
         if (down) {
             QColor downColor;
-            if (m_type == CloseButton && active && Handler()->redCloseButton()) {
+            if (type() == CloseButton && active && Handler()->redCloseButton()) {
                 downColor = QColor(220,65,65).dark(115);
             } else if (Handler()->customColors()) {
                 downColor = Handler()->getColor(BtnBg, active).dark(115);
@@ -470,10 +417,15 @@ void SUSE2Button::drawLipstikBtn(QPainter *painter)
 
         int dX,dY;
         KPixmap deco;
-        int s = lroundf(r.height()*Handler()->iconSize());
+        int s = lroundf(r.height() * Handler()->iconSize());
         if ((s + r.height())%2 != 0) --s;
 
-        deco = active ? Handler()->buttonPixmap(btnType, s, A_FG_DARK) : Handler()->buttonPixmap(btnType, s, I_FG_DARK);
+        if (down) {
+            deco = active ? Handler()->buttonPixmap(m_iconType, s, ActiveDown) : Handler()->buttonPixmap(m_iconType, s, InactiveDown);
+        } else {
+            deco = active ? Handler()->buttonPixmap(m_iconType, s, ActiveUp) : Handler()->buttonPixmap(m_iconType, s, InactiveUp);
+        }
+
         dX = r.x()+(r.width()-deco.width())/2;
         dY = r.y()+(r.height()-deco.height())/2;
         if (down) {
@@ -482,7 +434,7 @@ void SUSE2Button::drawLipstikBtn(QPainter *painter)
 
         if(active && !down &&
            (Handler()->useTitleProps() && Handler()->titleShadow() || Handler()->iconShadow())) {
-            bP.drawPixmap(dX+1, dY+1, Handler()->buttonPixmap(btnType, s, SHADOW));
+            bP.drawPixmap(dX+1, dY+1, Handler()->buttonPixmap(m_iconType, s, Shadow));
         }
 
         bP.drawPixmap(dX, dY, deco);
@@ -500,7 +452,7 @@ void SUSE2Button::renderBtnContour(QPainter *p, const QRect &r)
     bool active = m_client->isActive();
 
     QColor backgroundColor;
-    if (m_type == CloseButton && active && Handler()->redCloseButton()) {
+    if (type() == CloseButton && active && Handler()->redCloseButton()) {
         backgroundColor = QColor(220,65,65);
     } else if (Handler()->customColors()) {
         backgroundColor = Handler()->getColor(BtnBg, active);
@@ -531,17 +483,18 @@ void SUSE2Button::renderBtnContour(QPainter *p, const QRect &r)
     p->setPen( backgroundColor );
 
     // third part... anti-aliasing...
-    renderPixel(p,QPoint(r.left()+1,r.top()),alphaAA,contourColor);
-    renderPixel(p,QPoint(r.left(),r.top()+1),alphaAA,contourColor);
-    renderPixel(p,QPoint(r.left()+1,r.bottom()),alphaAA,contourColor);
-    renderPixel(p,QPoint(r.left(),r.bottom()-1),alphaAA,contourColor);
-    renderPixel(p,QPoint(r.right()-1,r.top()),alphaAA,contourColor);
-    renderPixel(p,QPoint(r.right(),r.top()+1),alphaAA,contourColor);
-    renderPixel(p,QPoint(r.right()-1,r.bottom()),alphaAA,contourColor);
-    renderPixel(p,QPoint(r.right(),r.bottom()-1),alphaAA,contourColor);
+    int intActive = active ? 0 : 1;
+    renderPixel(p,QPoint(r.left()+1,r.top()),alphaAA,contourColor, 0, intActive);
+    renderPixel(p,QPoint(r.left(),r.top()+1),alphaAA,contourColor, 1, intActive);
+    renderPixel(p,QPoint(r.left()+1,r.bottom()),alphaAA,contourColor, 2, intActive);
+    renderPixel(p,QPoint(r.left(),r.bottom()-1),alphaAA,contourColor, 3, intActive);
+    renderPixel(p,QPoint(r.right()-1,r.top()),alphaAA,contourColor, 4, intActive);
+    renderPixel(p,QPoint(r.right(),r.top()+1),alphaAA,contourColor, 5, intActive);
+    renderPixel(p,QPoint(r.right()-1,r.bottom()),alphaAA,contourColor, 6, intActive);
+    renderPixel(p,QPoint(r.right(),r.bottom()-1),alphaAA,contourColor, 7, intActive);
 }
 
-void SUSE2Button::renderBtnSurface(QPainter *p, const QRect &r) const
+void SUSE2Button::renderBtnSurface(QPainter *p, const QRect &r)
 {
     if((r.width() <= 0)||(r.height() <= 0))
         return;
@@ -549,7 +502,7 @@ void SUSE2Button::renderBtnSurface(QPainter *p, const QRect &r) const
     bool active = m_client->isActive();
 
     QColor backgroundColor;
-    if (m_type == CloseButton && active && Handler()->redCloseButton()) {
+    if (type() == CloseButton && active && Handler()->redCloseButton()) {
         backgroundColor = QColor(220,65,65);
     } else if (Handler()->customColors()) {
         backgroundColor = Handler()->getColor(BtnBg, active);
@@ -558,13 +511,13 @@ void SUSE2Button::renderBtnSurface(QPainter *p, const QRect &r) const
     }
 
     QColor highlightColor;
-    if(m_type == CloseButton) {
+    if(type() == CloseButton) {
         highlightColor = QColor(255,0,0);
     } else {
         highlightColor = Qt::white;
     }
 
-    int highlightAlpha = static_cast<int>(255-((60/static_cast<double>(ANIMATIONSTEPS))*
+    int highlightAlpha = static_cast<int>(255-((60/static_cast<double>(ANIMATIONSTEPS)) *
                                           static_cast<double>(animProgress) ) );
 
     QColor buttonColor, bottomColor, topLineColor, bottomLineColor;
@@ -586,11 +539,13 @@ void SUSE2Button::renderBtnSurface(QPainter *p, const QRect &r) const
     topLineColor = alphaBlendColors(topLineColor, highlightColor, highlightAlpha);
     bottomLineColor = alphaBlendColors(bottomLineColor, highlightColor, highlightAlpha);
 
+    int intActive = active ? 0 : 1;
+
 // sides,left
     int height = r.height() - 2;
-    renderGradient(p, QRect(r.left(), r.top()+1, 1, height), bottomColor, buttonColor);
+    renderGradient(p, QRect(r.left(), r.top()+1, 1, height), bottomColor, buttonColor, 8+animProgress, intActive);
 //right
-    renderGradient(p, QRect(r.right(), r.top()+1, 1, height), bottomColor, buttonColor);
+    renderGradient(p, QRect(r.right(), r.top()+1, 1, height), bottomColor, buttonColor, 9+ANIMATIONSTEPS+animProgress, intActive);
 //top
     p->setPen(topLineColor);
     p->drawLine(r.left()+1, r.top(), r.right()-1, r.top() );
@@ -603,30 +558,17 @@ void SUSE2Button::renderBtnSurface(QPainter *p, const QRect &r) const
     height = r.height();
     width-=2;
     height-=2;
-    renderGradient(p, QRect(r.left()+1, r.top()+1, width, height),  bottomColor, buttonColor);
+    renderGradient(p, QRect(r.left()+1, r.top()+1, width, height),  bottomColor, buttonColor,
+                   10 + 2 * ANIMATIONSTEPS+animProgress, intActive);
 }
 
-void SUSE2Button::renderPixel(QPainter *p,
-        		       const QPoint &pos,
-        		       const int alpha,
-        		       const QColor &color) const
+void SUSE2Button::renderPixel(QPainter *p, const QPoint &pos, const int alpha, const QColor &color,
+                              const int pixelPos, const int active)
 {
+    if (lipstikCache[pixelPos][active]) {
+        p->drawPixmap(pos, *(lipstikCache[pixelPos][active]));
+    } else {
         QRgb rgb = color.rgb();
-        // generate a quite unique key -- use the unused width field to store the alpha value.
-        CacheEntry search(cAlphaDot, alpha, 0, rgb);
-        int key = search.key();
-
-        CacheEntry *cacheEntry;
-        if( (cacheEntry = pixmapCache->find(key)) ) {
-            if( search == *cacheEntry ) { // match! we can draw now...
-                if(cacheEntry->pixmap)
-                    p->drawPixmap(pos, *(cacheEntry->pixmap) );
-                return;
-            } else { //Remove old entry in case of a conflict!
-                pixmapCache->remove( key );
-            }
-        }
-
         QImage aImg(1,1,32); // 1x1
         aImg.setAlphaBuffer(true);
         aImg.setPixel(0,0,qRgba(qRed(rgb),qGreen(rgb),qBlue(rgb),alpha));
@@ -635,89 +577,63 @@ void SUSE2Button::renderPixel(QPainter *p,
         p->drawPixmap(pos, *result);
 
         // add to the cache...
-        CacheEntry *toAdd = new CacheEntry(search);
-        toAdd->pixmap = result;
-        bool insertOk = pixmapCache->insert( key, toAdd, result->depth()/8);
-        if(!insertOk)
-            delete result;
+        lipstikCache[pixelPos][active] = result;
+    }
 }
 
-void SUSE2Button::renderGradient(QPainter *painter,
-                                  const QRect &rect,
-                                  const QColor &c1,
-                                  const QColor &c2) const
+void SUSE2Button::renderGradient(QPainter *painter, const QRect &rect, const QColor &c1, const QColor &c2,
+                                 const int gradient, const int active)
 {
-   if((rect.width() <= 0)||(rect.height() <= 0))
+    if((rect.width() <= 0)||(rect.height() <= 0))
         return;
 
-    // generate a quite unique key for this surface.
-    CacheEntry search(cGradientTile, 0, rect.height(), c2.rgb(), c1.rgb());
-    int key = search.key();
+    if (lipstikCache[gradient][active]) {
+        painter->drawTiledPixmap(rect, *(lipstikCache[gradient][active]));
+    } else {
+        // there wasn't anything matching in the cache, create the pixmap now...
+        QPixmap *result = new QPixmap(10, rect.height());
+        QPainter p(result);
 
-    CacheEntry *cacheEntry;
-    if( (cacheEntry = pixmapCache->find(key)) ) {
-        if( search == *cacheEntry ) { // match! we can draw now...
-            if(cacheEntry->pixmap) {
-                painter->drawTiledPixmap(rect, *(cacheEntry->pixmap) );
-            }
-            return;
-        } else {
-            // Remove old entry in case of a conflict!
-            // This shouldn't happen very often, see comment in CacheEntry.
-            pixmapCache->remove(key);
+        int r_h = result->rect().height();
+        int r_x, r_y, r_x2, r_y2;
+        result->rect().coords(&r_x, &r_y, &r_x2, &r_y2);
+
+        int rDiff, gDiff, bDiff;
+        int rc, gc, bc;
+
+        register int y;
+
+        rDiff = ( c1.red())   - (rc = c2.red());
+        gDiff = ( c1.green()) - (gc = c2.green());
+        bDiff = ( c1.blue())  - (bc = c2.blue());
+
+        register int rl = rc << 16;
+        register int gl = gc << 16;
+        register int bl = bc << 16;
+
+        int rdelta = ((1<<16) / r_h) * rDiff;
+        int gdelta = ((1<<16) / r_h) * gDiff;
+        int bdelta = ((1<<16) / r_h) * bDiff;
+
+        // these for-loops could be merged, but the if's in the inner loop
+        // would make it slow
+        for ( y = 0; y < r_h; y++ ) {
+            rl += rdelta;
+            gl += gdelta;
+            bl += bdelta;
+
+            p.setPen(QColor(rl>>16, gl>>16, bl>>16));
+            p.drawLine(r_x, r_y+y, r_x2, r_y+y);
         }
+
+        p.end();
+
+        // draw the result...
+        painter->drawTiledPixmap(rect, *result);
+
+        // add to the cache...
+        lipstikCache[gradient][active] = result;
     }
-
-    // there wasn't anything matching in the cache, create the pixmap now...
-    QPixmap *result = new QPixmap(10, rect.height());
-    QPainter p(result);
-
-//    int r_w = result->rect().width();
-    int r_h = result->rect().height();
-    int r_x, r_y, r_x2, r_y2;
-    result->rect().coords(&r_x, &r_y, &r_x2, &r_y2);
-
-    int rDiff, gDiff, bDiff;
-    int rc, gc, bc;
-
-    register int y;
-
-
-    rDiff = ( c1.red())   - (rc = c2.red());
-    gDiff = ( c1.green()) - (gc = c2.green());
-    bDiff = ( c1.blue())  - (bc = c2.blue());
-
-    register int rl = rc << 16;
-    register int gl = gc << 16;
-    register int bl = bc << 16;
-
-    int rdelta = ((1<<16) / r_h) * rDiff;
-    int gdelta = ((1<<16) / r_h) * gDiff;
-    int bdelta = ((1<<16) / r_h) * bDiff;
-
-    // these for-loops could be merged, but the if's in the inner loop
-    // would make it slow
-    for ( y = 0; y < r_h; y++ ) {
-        rl += rdelta;
-        gl += gdelta;
-        bl += bdelta;
-
-        p.setPen(QColor(rl>>16, gl>>16, bl>>16));
-        p.drawLine(r_x, r_y+y, r_x2, r_y+y);
-    }
-
-    p.end();
-
-    // draw the result...
-    painter->drawTiledPixmap(rect, *result);
-
-    // insert into cache using the previously created key.
-    CacheEntry *toAdd = new CacheEntry(search);
-    toAdd->pixmap = result;
-    bool insertOk = pixmapCache->insert( key, toAdd, result->width()*result->height()*result->depth()/8 );
-
-    if(!insertOk)
-        delete result;
 }
 
 QBitmap IconEngine::icon(ButtonIcon icon, int size)
@@ -787,36 +703,36 @@ QBitmap IconEngine::icon(ButtonIcon icon, int size)
             }
 
             int margin1, margin2;
-            margin1 = margin2 = lineWidth2*2;
+            margin1 = margin2 = lineWidth2 * 2;
             if (r.width() < 8)
                 margin1 = 1;
 
             // background window
             drawObject(p, HorizontalLine, r.x()+margin1, r.top(), r.width()-margin1, lineWidth2);
-            drawObject(p, HorizontalLine, r.right()-margin2, r.bottom()-(lineWidth2-1)-margin1, margin2, lineWidth2);
+            drawObject(p, HorizontalLine, r.right()-margin2, r.bottom()-(lineWidth2 - 1)-margin1, margin2, lineWidth2);
             drawObject(p, VerticalLine, r.x()+margin1, r.top(), margin2, lineWidth2);
-            drawObject(p, VerticalLine, r.right()-(lineWidth2-1), r.top(), r.height()-margin1, lineWidth2);
+            drawObject(p, VerticalLine, r.right()-(lineWidth2 - 1), r.top(), r.height()-margin1, lineWidth2);
 
             // foreground window
             drawObject(p, HorizontalLine, r.x(), r.top()+margin2, r.width()-margin2, lwTitleBar);
-            drawObject(p, HorizontalLine, r.x(), r.bottom()-(lineWidth2-1), r.width()-margin2, lineWidth2);
+            drawObject(p, HorizontalLine, r.x(), r.bottom()-(lineWidth2 - 1), r.width()-margin2, lineWidth2);
             drawObject(p, VerticalLine, r.x(), r.top()+margin2, r.height(), lineWidth2);
-            drawObject(p, VerticalLine, r.right()-(lineWidth2-1)-margin2, r.top()+margin2, r.height(), lineWidth2);
+            drawObject(p, VerticalLine, r.right()-(lineWidth2 - 1)-margin2, r.top()+margin2, r.height(), lineWidth2);
 
             break;
         }
 
         case MinIcon:
         {
-            drawObject(p, HorizontalLine, r.x(), r.bottom()-(lwTitleBar-1), r.width(), lwTitleBar);
+            drawObject(p, HorizontalLine, r.x(), r.bottom()-(lwTitleBar - 1), r.width(), lwTitleBar);
 
             break;
         }
 
         case HelpIcon:
         {
-            int center = r.x()+r.width()/2 -1;
-            int side = r.width()/4;
+            int center = r.x()+r.width() / 2 - 1;
+            int side = r.width() / 4;
 
             // paint a question mark... code is quite messy, to be cleaned up later...! :o
 
@@ -824,9 +740,9 @@ QBitmap IconEngine::icon(ButtonIcon icon, int size)
                 int lineWidth = 3;
 
                 // top bar
-                drawObject(p, HorizontalLine, center-side+3, r.y(), 2*side-3-1, lineWidth);
+                drawObject(p, HorizontalLine, center-side + 3, r.y(), 2 * side - 3 - 1, lineWidth);
                 // top bar rounding
-                drawObject(p, CrossDiagonalLine, center-side-1, r.y()+5, 6, lineWidth);
+                drawObject(p, CrossDiagonalLine, center - side - 1, r.y() + 5, 6, lineWidth);
                 drawObject(p, DiagonalLine, center+side-3, r.y(), 5, lineWidth);
                 // right bar
                 drawObject(p, VerticalLine, center+side+2-lineWidth, r.y()+3, r.height()-(2*lineWidth+side+2+1), lineWidth);
@@ -1059,3 +975,5 @@ void IconEngine::drawObject(QPainter &p, Object object, int x, int y, int length
 }
 
 } // KWinSUSE2
+
+// kate: space-indent on; indent-width 4; replace-tabs on;
