@@ -66,7 +66,7 @@ SUSE2Client::~SUSE2Client()
 // pure virtual methods from KCommonDecoration
 QString SUSE2Client::visibleName() const
 {
-    return i18n("SUSE2 (Version %1)").arg("0.3.5");
+    return i18n("SUSE2 (Version %1)").arg("0.4");
 }
 
 QString SUSE2Client::defaultButtonsLeft() const
@@ -135,18 +135,10 @@ int SUSE2Client::layoutMetric(LayoutMetric lm, bool respectWindowState, const KC
     switch (lm) {
         case LM_BorderLeft:
         case LM_BorderRight:
-            if (respectWindowState && maximized) {
-                return 0;
-            } else {
-                return Handler()->borderSize();
-            }
-
         case LM_BorderBottom:
-            if (respectWindowState && maximized && !isShade()) {
+            if (respectWindowState && maximized)
                 return 0;
-            } else {
-                return Handler()->borderSize();
-            }
+            return Handler()->borderSize();
 
         case LM_TitleEdgeTop:
             if (respectWindowState && maximized) {
@@ -165,7 +157,7 @@ int SUSE2Client::layoutMetric(LayoutMetric lm, bool respectWindowState, const KC
         case LM_TitleEdgeLeft:
         case LM_TitleEdgeRight:
             if (respectWindowState && maximized) {
-                return 1;
+                return 0;
             } else {
                 return 6;
             }
@@ -176,12 +168,6 @@ int SUSE2Client::layoutMetric(LayoutMetric lm, bool respectWindowState, const KC
 
         case LM_ButtonWidth:
         case LM_ButtonHeight:
-            if (respectWindowState && isToolWindow()) {
-                return Handler()->titleHeightTool();
-            } else {
-                return Handler()->titleHeight() - 1;
-            }
-
         case LM_TitleHeight:
             if (respectWindowState && isToolWindow()) {
                 return Handler()->titleHeightTool();
@@ -193,11 +179,7 @@ int SUSE2Client::layoutMetric(LayoutMetric lm, bool respectWindowState, const KC
             return 1;
 
         case LM_ButtonMarginTop:
-            if (respectWindowState && maximized) {
-                return 1;
-            } else {
-                return 0;
-            }
+            return 0;
 
         case LM_ExplicitButtonSpacer:
             return 3;
@@ -616,17 +598,35 @@ void SUSE2Client::create_pixmaps()
     aTitleBarTile = new QPixmap(1, titleHeight + TOPMARGIN + DECOHEIGHT);
     painter.begin(aTitleBarTile);
     painter.drawPixmap(0, 0, tempPixmap);
-    QImage t(1, (titleHeight + TOPMARGIN + DECOHEIGHT)/2 + 1, 32 );
-    t = KImageEffect::gradient(QSize(1, t.height()),
-                               Handler()->getColor(TitleGradientFrom, true).light(150),
-                               Handler()->getColor(TitleGradientTo, true).light(110),
-                               KImageEffect::VerticalGradient);
-    painter.drawImage(0, 2, t, 0, 0, -1, tempPixmap.height()-2);
-    t = KImageEffect::gradient(QSize(1, t.height()),
-                               Handler()->getColor(TitleGradientTo, true),
-                               Handler()->getColor(TitleGradientFrom, true),
-                               KImageEffect::VerticalGradient);
-    painter.drawImage(0, t.height(), t, 0, 0, -1, t.height());
+
+    QImage t;
+    if (Handler()->titlebarStyle() == 0) { // new, Toplight
+        t = QImage(1, (titleHeight + TOPMARGIN + DECOHEIGHT)/3 + 1, 32 );
+        t = KImageEffect::gradient(QSize(1, t.height()),
+                                Handler()->getColor(TitleGradientFrom, true).light(130),
+                                Handler()->getColor(TitleGradientTo, true),
+                                KImageEffect::VerticalGradient/*, 100, 100*/);
+        painter.drawImage(0, 2, t, 0, 0, -1, tempPixmap.height()-2);
+        t.create(t.width(), t.height()*2, t.depth());
+        t = KImageEffect::unbalancedGradient(QSize(1, t.height()),
+                                Handler()->getColor(TitleGradientTo, true),
+                                Handler()->getColor(TitleGradientFrom, true),
+                                KImageEffect::VerticalGradient, 100, 100);
+        painter.drawImage(0, t.height()/2, t, 0, 0, -1, t.height());
+    } else { // older, Balanced
+        t = QImage(1, (titleHeight + TOPMARGIN + DECOHEIGHT)/2 + 1, 32 );
+        t = KImageEffect::gradient(QSize(1, t.height()),
+                                Handler()->getColor(TitleGradientFrom, true).light(150),
+                                Handler()->getColor(TitleGradientTo, true).light(110),
+                                KImageEffect::VerticalGradient);
+        painter.drawImage(0, 2, t, 0, 0, -1, tempPixmap.height()-2);
+        t = KImageEffect::gradient(QSize(1, t.height()),
+                                Handler()->getColor(TitleGradientTo, true),
+                                Handler()->getColor(TitleGradientFrom, true),
+                                KImageEffect::VerticalGradient);
+        painter.drawImage(0, t.height(), t, 0, 0, -1, t.height());
+    }
+
     painter.end();
 
     // iTitleBarTile
@@ -675,9 +675,11 @@ void SUSE2Client::update_captionBuffer()
     int logoOffset = Handler()->titleLogoOffset();
     QFontMetrics fm(s_titleFont);
     int captionWidth  = fm.width(c);
+    int logoWidth = 0;
 
     if (Handler()->titleLogo()) {
-        captionWidth += logo.width() + logoOffset;
+        logoWidth = logo.width() + logoOffset;
+        captionWidth += logoWidth;
         if (logo.height()+1 > fm.height())
             logo.scaleHeight(fm.height()-1);
     }
@@ -721,19 +723,13 @@ void SUSE2Client::update_captionBuffer()
     }
     painter.setFont(s_titleFont);
     painter.setPen(Handler()->getColor(TitleFont,true));
-    if (Handler()->titleLogo()) {
-        painter.drawText(aCaptionBuffer->rect().left(), aCaptionBuffer->rect().top() + titleEdgeTop,
-                         aCaptionBuffer->rect().width()-logo.width()-logoOffset, aCaptionBuffer->rect().height() - titleEdgeTop-titleEdgeBottom,
-                         AlignCenter, c);
+    painter.drawText(aCaptionBuffer->rect().left(), aCaptionBuffer->rect().top() + titleEdgeTop,
+            aCaptionBuffer->rect().width()-logoWidth, aCaptionBuffer->rect().height() - titleEdgeTop-titleEdgeBottom,
+            AlignCenter, c);
+    if (Handler()->titleLogo())
         painter.drawImage(captionWidth - logo.width(), aCaptionBuffer->rect().top() + TOPMARGIN, logo);
-    } else {
-        painter.drawText(aCaptionBuffer->rect().left(), aCaptionBuffer->rect().top() + titleEdgeTop,
-                         aCaptionBuffer->rect().width(), aCaptionBuffer->rect().height() - titleEdgeTop - titleEdgeBottom,
-                         AlignCenter, c);
-    }
     painter.end();
 
-
     // inactive -> no shadow and no logo
     iCaptionBuffer->resize(captionWidth+4, titleHeight + TOPMARGIN + DECOHEIGHT);
     painter.begin(iCaptionBuffer);
@@ -741,7 +737,7 @@ void SUSE2Client::update_captionBuffer()
     painter.setFont(s_titleFont);
     painter.setPen(Handler()->getColor(TitleFont,false));
     painter.drawText(iCaptionBuffer->rect().left(), iCaptionBuffer->rect().top() + titleEdgeTop,
-                     iCaptionBuffer->rect().width(), iCaptionBuffer->rect().height() - titleEdgeTop - titleEdgeBottom,
+                     iCaptionBuffer->rect().width() - logoWidth, iCaptionBuffer->rect().height() - titleEdgeTop - titleEdgeBottom,
                      AlignCenter, c);
     painter.end();
 
